<?php
/**
 * @version   1.7 February 19, 2015
 * @author    RocketTheme http://www.rockettheme.com
 * @copyright Copyright (C) 2007 - 2015 RocketTheme, LLC
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

// no direct access
defined('ROKWEATHER') or die('Restricted access');

global $rokweather_plugin_path;

require_once $rokweather_plugin_path . '/cache.class.php';
require_once $rokweather_plugin_path . '/fileCacheDriver.class.php';

class RokWeather
{

	static $instance;
	static $widget_id;

	// Enqueue frontend styles and scripts
	public function rokweather_scripts() {
		global $rokweather_plugin_url;

		$global_option = get_option('widget_rokweather_globals');

		// Enqueue Style
		wp_enqueue_style('rokweather_css', $rokweather_plugin_url . '/rokweather.css');

		if($global_option == false) :
			$global_option = array();
		endif;

		// Enqueue Script
		if (array_key_exists('user_interaction', $global_option) && $global_option['user_interaction'] == '1') {
			wp_enqueue_script('rokweather_js', $rokweather_plugin_url . '/tmpl/js/rokweather.js');
		}
	}

	// Enqueue admin styles
	public function rokweather_admin_scripts() {
		global $rokweather_plugin_url;

		wp_enqueue_style('rokweather_admin_css', $rokweather_plugin_url . '/admin/rokweather.css');
	}

    public function getWeather($instance, $widget_id, $callback = false)
    {

        $weather_post = (string)strtolower($_REQUEST["weather_location"]);
        $weather_cookie = ($_COOKIE["wp_rokweather_location"][$widget_id]) ? (string)strtolower($_COOKIE["wp_rokweather_location"][$widget_id]) : $instance['default_location'];

        //if its a new location we don't want to use the cache
        if ($instance['enable_cache'] == '1' && ($weather_cookie == $weather_post)) {
			$cache = new RokWeather_Cache($defaultLifeTime = ((int)$instance['cache_time']) * 60);
			$cache->addDriver('file', new RokWeather_FileCacheDriver());
			$weather = unserialize($cache->get($instance['source'], $this->filename_safe($weather_cookie), ((int)$instance['cache_time']) * 60));
        } else {
            //get new weather if we can
            $weather = $this->_getWeather($instance, $widget_id, $callback);
            if (!is_object($weather)) {
                //bad call we get the cache anyways
				$cache = new RokWeather_Cache($defaultLifeTime = ((int)$instance['cache_time']) * 60);
				$cache->addDriver('file', new RokWeather_FileCacheDriver());
				$weather = unserialize($cache->get($instance['source'], $this->filename_safe($weather_cookie), ((int)$instance['cache_time']) * 60));
            }
        }

        return $weather;
    }

    public function _getWeather($instance, $widget_id, $callback)
    {
        $sources = RokWeather_SourceLoader::getAvailableSources(ROKWEATHER_ROOT . "/lib/RokWeather/Source");
        $selected_source = $instance['source'];

        foreach ($sources as $key => $source) {
            if ($key == $selected_source) {
                $weather = $source->source->getWeather($instance, $widget_id, $callback);

				if($instance['enable_cache'] == '1') {
					$cache = new RokWeather_Cache($defaultLifeTime = ((int)$instance['cache_time']) * 60);
					$cache->addDriver('file', new RokWeather_FileCacheDriver());
					$cache->set($selected_source, $this->filename_safe($weather->display_location), serialize($weather));
				}
            }
        }

        if (isset($weather->error)) {
            return $weather;
        }

        return $weather;
    }

    public static function addSourcesPath($path)
    {
        try {
            if (!RTCommon_ClassLoader::isLoaderRegistered('RokWeatherSources')) {
                $sourcesLoader = new RokWeather_SourceLoader();
                RTCommon_ClassLoader::registerLoader('RokWeatherSources', $sourcesLoader);
            } else {
                $sourcesLoader = RTCommon_ClassLoader::getLoader('RokWeatherSources');
            }
        } catch (Exception $le) {
            throw $le;
        }

        try {
            $sourcesLoader->addSourcePath($path);
        } catch (RTCommon_Cache_Exception $ce) {
            throw $ce;
        }
    }

    public static function getFTemp($temp, $units)
    {
        if ($units == "SI") {
            return intval((9 / 5) * intval($temp) + 32);
        } else {
            return $temp;
        }
    }

    public static function getCTemp($temp, $units)
    {
        if ($units == "SI") {
            return $temp;
        } else {
            return intval((5 / 9) * (intval($temp) - 32));
        }
    }

    public static function getWindspeed($type, $speed)
    {
        if (!$speed) return;
        switch ($type) {
            case 1:
                $number = preg_replace("/[^0-9]/", '', $speed);
                $speed = str_replace($number, floor($number * 1.609344), $speed);
                return str_replace('mph', 'kph', $speed);
                break;
            case 2:
                $number = preg_replace("/[^0-9]/", '', $speed);
                $speed = str_replace($number, floor($number * 0.868976242), $speed);
                return str_replace('mph', 'kts', $speed);
                break;
            default:
                return $speed;
                break;
        }
    }

	public static function getLocation($default_location, $override_location, $enable_cookie = "0", $widget_id)
    {
        if (isset($_REQUEST['weather_location'])) {
            $weather_location = trim($_POST['weather_location']);
            if ($enable_cookie == '1') {
                setcookie("wp_rokweather_location[$widget_id]", $weather_location, time() + 31536000, '/', false);
            }
        } elseif (isset($_COOKIE["wp_rokweather_location"]) && array_key_exists($widget_id, $_COOKIE["wp_rokweather_location"]) && $enable_cookie == '1') {
            $weather_location = $_COOKIE["wp_rokweather_location"][$widget_id];
        } else {
            if (in_array($override_location, array("", null, 1, 0))) {
                $weather_location = $default_location;
            } else {
                //we only want to change the display not the cookie
                $weather_location = $override_location;
            }
        }
        return $weather_location;
    }

	public static function filename_safe($filename) {
		$temp = $filename;
		$temp = strtolower($temp);
		$temp = str_replace(" ", "_", $temp);
		$result = '';
		for ($i=0; $i<strlen($temp); $i++) {
			if (preg_match('([0-9]|[a-z]|_)', $temp[$i])) {
				$result = $result . $temp[$i];
			}
		}
		return $result;
	}
}