<?php
/**
 * @version   1.7 February 19, 2015
 * @author    RocketTheme http://www.rockettheme.com
 * @copyright Copyright (C) 2007 - 2015 RocketTheme, LLC
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

defined('ROKWEATHER') or die('Restricted access');

class RokWeather_SourceLoader implements RTCommon_Loader
{

    const CLASS_NAME_PREFIX = 'RokWeatherSource';

    public function __construct()
    {
        $this->addSourcePath(dirname(__FILE__) . '/Source');
    }

    /**
     * @var array
     */
    private $_orderedPaths = array();
    private $_allPaths = array();

    public function addSourcePath($path, $priority = 10)
    {
        if (in_array($path, $this->_allPaths))
            return;
        if (!file_exists($path) || !is_dir($path))
        {
            throw new RokWeather_Exception($path . ' is not a valid directory.');
        }
        $this->_orderedPaths[$priority][$path] = $path;
        $this->_allPaths[] = $path;
    }

    /**
     * @param  string $className the class name to look for and load
     * @return bool True if the class was found and loaded.
     */
    public function loadClass($className)
    {
        $fileName = strtolower(str_replace(self::CLASS_NAME_PREFIX, '', $className) . self::FILE_EXTENSION);
        foreach ($this->_orderedPaths as $priority => $priorityPaths)
        {
            foreach ($priorityPaths as $path)
            {
                $full_file_path = $path . DIRECTORY_SEPARATOR . $fileName;
                if (file_exists($full_file_path) && is_readable($full_file_path))
                {
                    require($full_file_path);
                    return true;
                }

            }
        }
        return false;
    }

    public static function getAvailableSources($sourcedir)
    {
        $paths = self::getFrontsideTemplates();
        $paths[] = $sourcedir;

        foreach ($paths as $path)
        {
            RokWeather::addSourcesPath($path);
        }

        $results = array();
        foreach ($paths as $source_path)
        {
            if (file_exists($source_path))
            {
                $source_files = self::getDirectoryFiles($source_path);

                foreach ($source_files as $entry)
                {
                    $source_name = basename($entry, ".php");
                    $path = $source_path . DS . $source_name . '.php';
                    if (file_exists($path) && !array_key_exists($source_name, $results))
                    {
                        $sourceClass = self::CLASS_NAME_PREFIX . ucfirst($source_name);
                        $source = new $sourceClass();
                        if ($source->available())
                        {
                            $source_info = new stdClass();
                            $source_info->name = $source_name;
                            $source_info->source = $source;
                            $source_info->paramspath = $source_path . DS . $source_name . '.xml';
                            $results[$source_name] = $source_info;
                        }

                    }

                }
            }
        }

        return $results;
    }

    private static function getFrontsideTemplates()
    {
        $templateDirs = self::getFolders(WP_CONTENT_DIR . '/themes');
        $rows = array();
        foreach ($templateDirs as $templateDir)
        {
            $posible_sourcedir = $templateDir . "/html/plugins/wp_rokweather/sources";
            if (file_exists($posible_sourcedir) && is_dir($posible_sourcedir))
            {
                $rows[] = $posible_sourcedir;
            }
        }
        return $rows;
    }

	private static function getDirectoryFiles($path, $filter = '.', $recurse = false, $fullpath = false, $exclude = array('.svn', 'CVS', '.DS_Store')) {
		// Initialize variables
		$arr = array();

		// Check to make sure the path valid and clean
		$path = self::pathClean($path);

		// Is the path a folder?
		if (!is_dir($path)) {
			return false;
		}

		// read the source directory
		$handle = opendir($path);
		while (($file = readdir($handle)) !== false)
		{
			if (($file != '.') && ($file != '..') && (!in_array($file, $exclude))) {
				$dir = $path . DS . $file;
				$isDir = is_dir($dir);
				if ($isDir) {
					if ($recurse) {
						if (is_integer($recurse)) {
							$arr2 = self::getDirectoryFiles($dir, $filter, $recurse - 1, $fullpath);
						} else {
							$arr2 = self::getDirectoryFiles($dir, $filter, $recurse, $fullpath);
						}

						$arr = array_merge($arr, $arr2);
					}
				} else {
					if (preg_match("/$filter/", $file)) {
						if ($fullpath) {
							$arr[] = $path . DS . $file;
						} else {
							$arr[] = $file;
						}
					}
				}
			}
		}
		closedir($handle);

		asort($arr);
		return $arr;
	}

	private static function getFolders($path, $filter = '.', $recurse = false, $fullpath = false, $exclude = array('.svn', 'CVS', '.DS_Store')) {
		// Initialize variables
		$arr = array();

		// Check to make sure the path valid and clean
		$path = self::pathClean($path);

		// Is the path a folder?
		if (!is_dir($path)) {
			return false;
		}

		// read the source directory
		$handle = opendir($path);
		while (($file = readdir($handle)) !== false)
		{
			if (($file != '.') && ($file != '..') && (!in_array($file, $exclude))) {
				$dir = $path . DS . $file;
				$isDir = is_dir($dir);
				if ($isDir) {
					// Removes filtered directories
					if (preg_match("/$filter/", $file)) {
						if ($fullpath) {
							$arr[] = $dir;
						} else {
							$arr[] = $file;
						}
					}
					if ($recurse) {
						if (is_integer($recurse)) {
							$arr2 = self::getFolders($dir, $filter, $recurse - 1, $fullpath);
						} else {
							$arr2 = self::getFolders($dir, $filter, $recurse, $fullpath);
						}

						$arr = array_merge($arr, $arr2);
					}
				}
			}
		}
		closedir($handle);

		asort($arr);
		return $arr;
	}

	private static function pathClean($path, $ds=DS) {
		$path = trim($path);

		if (empty($path)) {
			$path = ABSPATH;
		} else {
			// Remove double slashes and backslahses and convert all slashes and backslashes to DS
			$path = preg_replace('#[/\\\\]+#', $ds, $path);
		}

		return $path;
	}
}
