<?php
/**
 * @version   1.7 February 19, 2015
 * @author    RocketTheme, LLC http://www.rockettheme.com
 * @copyright Copyright (C) 2007 - 2015 RocketTheme, LLC
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */
/*
Plugin Name: RokWeather
Plugin URI: http://www.rockettheme.com
Description: RokWeather, as the name suggests, is an Ajax-powered weather widget which utilizes the Google API allowing you to easily display weather data and related information from regions all across the globe.
Author: RocketTheme, LLC
Version: 1.7
Author URI: http://www.rockettheme.com
License: http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
*/

// No Direct Access
defined('ABSPATH') or die('Restricted access');

// Define Directory Separator
if (!defined('DS')) {
	define('DS', DIRECTORY_SEPARATOR);
}

// Globals
global $rokweather_plugin_path, $rokweather_plugin_url, $browser_platform, $browser_name, $browser_version;

$plugin_file = __FILE__;

if (isset($plugin)) {
	$plugin_file = $plugin;
} else if (isset($mu_plugin)) {
	$plugin_file = $mu_plugin;
} else if (isset($network_plugin)) {
	$plugin_file = $network_plugin;
}

$rokweather_plugin_path = WP_PLUGIN_DIR . '/' . basename(dirname($plugin_file));
$rokweather_plugin_url = WP_PLUGIN_URL . '/' . basename($rokweather_plugin_path);

// Define Constants
if (!defined('ROKWEATHER')) define('ROKWEATHER','ROKWEATHER');
if (!defined('ROKWEATHER_ROOT')) define('ROKWEATHER_ROOT', $rokweather_plugin_path);
if (!defined('ROKWEATHER_CACHE')) define('ROKWEATHER_CACHE', $rokweather_plugin_path . '/cache/');

// Includes
require(dirname(__FILE__) . '/rokbrowsercheck.php');
require_once(ROKWEATHER_ROOT . '/lib/include.php');

$browser_check = new RokBrowserCheck;
$browser_platform = $browser_check->platform;

// Widget
class RokWeatherWidget extends WP_Widget {

	// RocketTheme RokWeather Widget
	// Port by Jakub Baran

	static $plugin_path;
	static $plugin_url;
	static $global_params = array('user_interaction', 'default_degree');

	static $ROKWEATHER_ROOT;
	static $SOURCE_DIR;

	var $short_name = 'widget-rokweather';
	var $long_name = 'RokWeather';
	var $description = 'RocketTheme RokWeather Widget';
	var $css_classname = 'widget_rokweather';
	var $width = 280;
	var $height = 400;

	var $_defaults = array(
		'title' => '',
		'source' => 'yahoo',
		'default_location' => 'Golden, CO',
		'yahoo_default_location' => 'Golden, CO',
		'yahoo_location_override' => '',
		'yahoo_forecast_show' => '2',
		'wunderground_default_location' => 'Golden, CO',
		'wunderground_location_override' => '',
		'wunderground_forecast_show' => '4',
		'wunderground_api_key' => '',
		'wunderground_logo_style' => 'black',
		'location_override' => '',
		'default_degree' => '0',
		'user_interaction' => '1',
		'units_switch' => '1',
		'enable_cache' => '1',
		'cache_time' => '15',
		'enable_location_cookie' => '1',
		'enable_icon' => '1',
		'enable_humidity' => '1',
		'enable_wind' => '0',
		'wind_speed' => '0',
		'enable_forecast' => '1'
	);

	// Register RokWeather Widget
	function init() {
		register_widget('RokWeatherWidget');
	}

	// Initialise the widget
	function rokweather_init() {
		global $wp_registered_widgets;

		$option = get_option('widget_widget-rokweather');
		$sidebar_widgets = wp_get_sidebars_widgets();

		foreach ($sidebar_widgets as $sidebar => $sidebar_widgets) {
			if($sidebar != 'wp_inactive_widgets' && !empty($sidebar_widgets)) {
				foreach($sidebar_widgets as $widget) {
					if(strpos($widget, 'widget-rokweather-') !== false) {
						$widget_id = intval(str_replace('widget-rokweather-', '', $widget));
						$instance = $option[$widget_id];
						$weather_cookie = $_COOKIE["wp_rokweather_location"];

						if (isset($weather_cookie[$widget_id])) {
							$weather_location = trim($weather_cookie[$widget_id]);
						} else {
							$default_location_source = $instance['source'] . '_default_location';
							$weather_location = $instance[$default_location_source];
						}

						if($instance['enable_location_cookie'] == '1') {
							setcookie("wp_rokweather_location[$widget_id]", $weather_location, time()+31536000, '/', false);
						} else {
							setcookie("wp_rokweather_location[$widget_id]", false, 0);
							unset($_COOKIE["wp_rokweather_location"][$widget_id]);
						}
					}
				}
			}
		}
	}

	// Update global options
	function update($new_instance, $old_instance) {
		$global_instance = array();
		foreach (self::$global_params as $param) {
			if (array_key_exists($param, $new_instance)) {
				$global_instance[$param] = $new_instance[$param];
				unset($new_instance[$param]);
			}
		}
		update_option('widget_rokweather_globals', $global_instance);

		return $new_instance;
	}

	// Get global options
	function get_settings() {
		$global_option = get_option('widget_rokweather_globals');
		if($global_option == false) :
			$global_option = array();
		endif;
		$settings = parent::get_settings();
		foreach($settings as $key=>$setting) {
			if (count($setting) > 0) {
				$settings[$key] = array_merge($setting, $global_option);
			}
		}
		return $settings;
	}

	function render($args, $instance) {
		global $rokweather_plugin_path, $rokweather_plugin_url;

		$widget_id = false;
		$widget_id = $this->number;
		$global_option = get_option('widget_rokweather_globals');

		if($global_option == false) :
			$global_option = array();
		endif;

		if(array_key_exists('default_degree', $global_option)) :
			$defaultDegree = $global_option['default_degree'];
		else :
			$defaultDegree = '0';
		endif;

		$ajaxurl = get_bloginfo('wpurl') . '/wp-admin/admin-ajax.php?action=rokweather&moduleid=' . $widget_id;
		$output = "";

		$rokweather = new RokWeather();
		$weather = $rokweather->getWeather($instance, $widget_id);

		ob_start();

		// Before Widget
		echo $args['before_widget'];

		// Widget Title
		if($instance['title'] != '')
		echo $args['before_title'] . $instance['title'] . $args['after_title'];

		// Load Layouts

		if(file_exists(TEMPLATEPATH . '/html/plugins/wp_rokweather/default.php')) :
			require(TEMPLATEPATH . '/html/plugins/wp_rokweather/default.php');
		else :
			require($rokweather_plugin_path . '/tmpl/default.php');
		endif;

		// After Widget
		echo $args['after_widget'];

		$jsinit = "window.addEvent('domready', function() {new RokWeather({instance: '-" . $widget_id . "', defaultDegree: {$defaultDegree}});});";

		// Enqueue Script
		if (array_key_exists('user_interaction', $global_option) && $global_option['user_interaction'] == '1') {
			echo "\n<script type=\"text/javascript\">\n\n$jsinit\n\n</script>\n";
		}

		echo ob_get_clean();
	}

	function rokweather_callback() {
		global $rokweather_plugin_path, $rokweather_plugin_url;

		$widget_id = $_GET['moduleid'];
		$option = get_option('widget_widget-rokweather');
		$instance = $option[$widget_id];

		$ajaxurl = get_bloginfo('wpurl') . '/wp-admin/admin-ajax.php?action=rokweather&moduleid=' . $widget_id;
		$output = "";

		$rokweather = new RokWeather();
		$weather = $rokweather->getWeather($instance, $widget_id, $callback = true);

		// Load Layouts
		if(file_exists(TEMPLATEPATH . '/html/plugins/wp_rokweather/default.php')) :
			require(TEMPLATEPATH . '/html/plugins/wp_rokweather/default.php');
		else :
			require($rokweather_plugin_path . '/tmpl/default.php');
		endif;

		die();
	}

	function form($instance) {
		global $rokweather_plugin_path, $rokweather_plugin_url;

		self::$ROKWEATHER_ROOT = $rokweather_plugin_path;
		self::$SOURCE_DIR = self::$ROKWEATHER_ROOT . '/lib/RokWeather/Source';

		$defaults = $this->_defaults;
		$instance = wp_parse_args((array) $instance, $defaults);
		foreach ($instance as $variable => $value)
		{
			$$variable = self::_cleanOutputVariable($variable, $value);
			$instance[$variable] = $$variable;
		}
		$this->_values = $instance;

		//Find Sources
		$sources = RokWeather_SourceLoader::getAvailableSources(self::$SOURCE_DIR);
		$options = array();
		$selected = '';

		foreach ($sources as $source_name => $source) {
			// build the html list for content type
			$options[] = array(
				'text' => ucfirst($source->name),
				'value' => $source_name
			);
		}

		/*$js = "window.addEvent('load', function() {
			$('" . $this->get_field_id('source') . "').addEvent('change', function(){
				var sel = this.getSelected().get('value');
				$$('.source').getParent('p').setStyle('display','none');
				$$('.'+sel).getParent('p').setStyle('display','block');
			}).fireEvent('change');
		});";*/

		ob_start();

		?>

		<!-- Begin RokWeather Widget Admin -->
		<!--<script type="text/javascript">
			<?php echo $js; ?>
		</script>-->
		<div class="rokweather-admin-wrapper">
			<p>
				<label class="rok-tips" data-tips="Adds the widget title." for="<?php echo $this->get_field_id('title'); ?>">
					<?php _e('Title:', 'rokweather'); ?>
				</label>
				<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title']; ?>" />
			</p>

			<p>
				<label class="rok-tips" data-tips="Select the source of data." for="<?php echo $this->get_field_id('source'); ?>">
					<?php _e('Source:', 'rokweather'); ?>
				</label>
				<select name="<?php echo $this->get_field_name('source'); ?>" id="<?php echo $this->get_field_id('source'); ?>">
					<?php foreach ($options as $field) {
						($instance['source'] == $field['value']) ? $selected = 'selected="selected"' : $selected = ''; ?>
						<option value="<?php echo $field['value']; ?>" <?php echo $selected; ?>><?php echo $field['text']; ?></option>
					<?php } ?>
				</select>
			</p>

			<!-- YAHOO -->

			<p>
				<label class="rok-tips" data-tips="Valid location or US ZIP code." for="<?php echo $this->get_field_id('yahoo_default_location'); ?>">
					* <?php _e('Default Location:', 'rokweather'); ?>
				</label>
				<input class="widefat source yahoo" id="<?php echo $this->get_field_id('yahoo_default_location'); ?>" name="<?php echo $this->get_field_name('yahoo_default_location'); ?>" type="text" value="<?php echo $instance['yahoo_default_location']; ?>" />
			</p>

			<p>
				<label class="rok-tips" data-tips="A Location in the form of Default Location that will be shown instead. Useful when your town is not picked up by the API and you have to use the nearest city but want to still show your town name. &lt;br /&gt;Leave blank if you don't want overrides." for="<?php echo $this->get_field_id('yahoo_location_override'); ?>">
					* <?php _e('Location Override:', 'rokweather'); ?>
				</label>
				<input class="widefat source yahoo" id="<?php echo $this->get_field_id('yahoo_location_override'); ?>" name="<?php echo $this->get_field_name('yahoo_location_override'); ?>" type="text" value="<?php echo $instance['yahoo_location_override']; ?>" />
			</p>

			<p>
				<span style="background: #FFF3A3;border: 1px solid #E7BD72;color: #B79000;display: block;padding: 8px 10px;" width="100%" class="source yahoo">* <?php _e('If you have cookies enabled; Cookies must be cleared for the changes to take effect.', 'rokweather'); ?></span>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('yahoo_forecast_show'); ?>">
					<?php _e('Forecast items to show:', 'rokweather'); ?>
				</label>
				<select class="widefat source yahoo" id="<?php echo $this->get_field_id('yahoo_forecast_show'); ?>" name="<?php echo $this->get_field_name('yahoo_forecast_show'); ?>">
					<option value="1"<?php selected($instance['yahoo_forecast_show'], '1'); ?>><?php _e('1 day', 'rokweather'); ?></option>
					<option value="2"<?php selected($instance['yahoo_forecast_show'], '2'); ?>><?php _e('2 days', 'rokweather'); ?></option>
				</select>
			</p>

			<!-- Wunderground -->

			<p>
				<label class="rok-tips" data-tips="Valid location or US ZIP code." for="<?php echo $this->get_field_id('wunderground_default_location'); ?>">
					* <?php _e('Default Location:', 'rokweather'); ?>
				</label>
				<input class="widefat source wunderground" id="<?php echo $this->get_field_id('wunderground_default_location'); ?>" name="<?php echo $this->get_field_name('wunderground_default_location'); ?>" type="text" value="<?php echo $instance['wunderground_default_location']; ?>" />
			</p>

			<p>
				<label class="rok-tips" data-tips="A Location in the form of Default Location that will be shown instead. Useful when your town is not picked up by the API and you have to use the nearest city but want to still show your town name. &lt;br /&gt;Leave blank if you don't want overrides." for="<?php echo $this->get_field_id('wunderground_location_override'); ?>">
					* <?php _e('Location Override:', 'rokweather'); ?>
				</label>
				<input class="widefat source wunderground" id="<?php echo $this->get_field_id('wunderground_location_override'); ?>" name="<?php echo $this->get_field_name('wunderground_location_override'); ?>" type="text" value="<?php echo $instance['wunderground_location_override']; ?>" />
			</p>

			<p>
				<span style="background: #FFF3A3;border: 1px solid #E7BD72;color: #B79000;display: block;padding: 8px 10px;" width="100%" class="source wunderground">* <?php _e('If you have cookies enabled; Cookies must be cleared for the changes to take effect.', 'rokweather'); ?></span>
			</p>

			<p>
				<label class="rok-tips" data-tips="For Wunderground you must enter a API Key, you can get one at: http://www.wunderground.com/weather/api/" for="<?php echo $this->get_field_id('wunderground_api_key'); ?>">
					** <?php _e('Wunderground API Key:', 'rokweather'); ?>
				</label>
				<input class="widefat source wunderground" id="<?php echo $this->get_field_id('wunderground_api_key'); ?>" name="<?php echo $this->get_field_name('wunderground_api_key'); ?>" type="text" value="<?php echo $instance['wunderground_api_key']; ?>" />
			</p>

			<p>
				<span style="background: #d2edc9;border: 1px solid #90e772;color: #2b7312;display: block;padding: 8px 10px;" class="source wunderground">** <?php _e('You must enter an API Key for Wunderground:', 'rokweather'); ?> <a target="_blank" href="http://www.wunderground.com/weather/api/"><?php _e('Apply for Wunderground API Key', 'rokweather'); ?></a></span>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('wunderground_forecast_show'); ?>">
					<?php _e('Forecast items to show:', 'rokweather'); ?>
				</label>
				<select class="widefat source wunderground" id="<?php echo $this->get_field_id('wunderground_forecast_show'); ?>" name="<?php echo $this->get_field_name('wunderground_forecast_show'); ?>">
					<option value="1"<?php selected($instance['wunderground_forecast_show'], '1'); ?>><?php _e('1 day', 'rokweather'); ?></option>
					<option value="2"<?php selected($instance['wunderground_forecast_show'], '2'); ?>><?php _e('2 days', 'rokweather'); ?></option>
					<option value="3"<?php selected($instance['wunderground_forecast_show'], '3'); ?>><?php _e('3 days', 'rokweather'); ?></option>
					<option value="4"<?php selected($instance['wunderground_forecast_show'], '4'); ?>><?php _e('4 days', 'rokweather'); ?></option>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('wunderground_logo_style'); ?>">
					<?php _e('Wunderground Logo Style:', 'rokweather'); ?>
				</label>
				<select class="widefat source wunderground" id="<?php echo $this->get_field_id('wunderground_logo_style'); ?>" name="<?php echo $this->get_field_name('wunderground_logo_style'); ?>">
					<option value="black"<?php selected($instance['wunderground_logo_style'], 'black'); ?>><?php _e('Black', 'rokweather'); ?></option>
					<option value="white"<?php selected($instance['wunderground_logo_style'], 'white'); ?>><?php _e('White', 'rokweather'); ?></option>
				</select>
			</p>

			<p>
				<img src="<?php echo $rokweather_plugin_url; ?>/images/wundergroundLogo_<?php echo $instance['wunderground_logo_style']; ?>_horz.png" alt="wunderground.com&reg; logo" class="source wunderground rok-wunderground-logo"/>
			</p>

			<p>
				<div class="col-left">
					<label class="rok-tips" data-tips="The default Degree Type to use." for="<?php echo $this->get_field_id('default_degree'); ?>">
						<?php _e('Default Degree Type:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('default_degree'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('default_degree'); ?>" <?php if($instance['default_degree'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('default_degree'); ?>0">&#x2109;</label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('default_degree'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('default_degree'); ?>" <?php if($instance['default_degree'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('default_degree'); ?>1">&#x2103;</label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label class="rok-tips" data-tips="Gives to the user the ability to interact with RokWeather. Note: all modifications will be visible to the user only. If enabled cookies must be cleaned." for="<?php echo $this->get_field_id('user_interaction'); ?>">
						<?php _e('User Interaction:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('user_interaction'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('user_interaction'); ?>" <?php if($instance['user_interaction'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('user_interaction'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('user_interaction'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('user_interaction'); ?>" <?php if($instance['user_interaction'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('user_interaction'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label class="rok-tips" data-tips="Enable or disable the ability to switch between units temperatures. If disabled, will be kept the Default Degree Type unit." for="<?php echo $this->get_field_id('units_switch'); ?>">
						<?php _e('Enable Units switch:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('units_switch'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('units_switch'); ?>" <?php if($instance['units_switch'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('units_switch'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('units_switch'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('units_switch'); ?>" <?php if($instance['units_switch'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('units_switch'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label class="rok-tips" data-tips="Enable location cache" for="<?php echo $this->get_field_id('enable_cache'); ?>">
						<?php _e('Location Caching:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('enable_cache'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('enable_cache'); ?>" <?php if($instance['enable_cache'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_cache'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('enable_cache'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('enable_cache'); ?>" <?php if($instance['enable_cache'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_cache'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label for="<?php echo $this->get_field_id('enable_location_cookie'); ?>">
						<?php _e('Enable Location Cookie:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('enable_location_cookie'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('enable_location_cookie'); ?>" <?php if($instance['enable_location_cookie'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_location_cookie'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('enable_location_cookie'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('enable_location_cookie'); ?>" <?php if($instance['enable_location_cookie'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_location_cookie'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label for="<?php echo $this->get_field_id('enable_icon'); ?>">
						<?php _e('Enable Icon Display:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('enable_icon'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('enable_icon'); ?>" <?php if($instance['enable_icon'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_icon'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('enable_icon'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('enable_icon'); ?>" <?php if($instance['enable_icon'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_icon'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label for="<?php echo $this->get_field_id('enable_humidity'); ?>">
						<?php _e('Enable Humidity Display:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('enable_humidity'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('enable_humidity'); ?>" <?php if($instance['enable_humidity'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_humidity'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('enable_humidity'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('enable_humidity'); ?>" <?php if($instance['enable_humidity'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_humidity'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label for="<?php echo $this->get_field_id('enable_wind'); ?>">
						<?php _e('Enable Wind Display:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('enable_wind'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('enable_wind'); ?>" <?php if($instance['enable_wind'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_wind'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('enable_wind'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('enable_wind'); ?>" <?php if($instance['enable_wind'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_wind'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label for="<?php echo $this->get_field_id('wind_speed'); ?>">
						<?php _e('Default Windspeed Type:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('wind_speed'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('wind_speed'); ?>" <?php if($instance['wind_speed'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('wind_speed'); ?>0"><?php _e('MPH', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('wind_speed'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('wind_speed'); ?>" <?php if($instance['wind_speed'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('wind_speed'); ?>1"><?php _e('KPH', 'rokweather'); ?></label>
					<input id="<?php echo $this->get_field_id('wind_speed'); ?>2" type="radio" value="2" name="<?php echo $this->get_field_name('wind_speed'); ?>" <?php if($instance['wind_speed'] == '2') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('wind_speed'); ?>2"><?php _e('KTS', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>

			<p>
				<div class="col-left">
					<label for="<?php echo $this->get_field_id('enable_forecast'); ?>">
						<?php _e('Enable Weather Forecast:', 'rokweather'); ?>
					</label>
				</div>
				<div class="col-right">
					<input id="<?php echo $this->get_field_id('enable_forecast'); ?>0" type="radio" value="0" name="<?php echo $this->get_field_name('enable_forecast'); ?>" <?php if($instance['enable_forecast'] == '0') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_forecast'); ?>0"><?php _e('No', 'rokweather'); ?></label>&nbsp;&nbsp;
					<input id="<?php echo $this->get_field_id('enable_forecast'); ?>1" type="radio" value="1" name="<?php echo $this->get_field_name('enable_forecast'); ?>" <?php if($instance['enable_forecast'] == '1') echo 'checked="checked"'; ?>/>
					<label for="<?php echo $this->get_field_id('enable_forecast'); ?>1"><?php _e('Yes', 'rokweather'); ?></label>
				</div>
				<div class="clear"></div>
			</p>
		</div>

		<!-- End RokWeather Widget Admin -->

		<?php

		echo ob_get_clean();
	}

	/********** Bellow here should not need to be changed ***********/

	function __construct() {
		if (empty($this->short_name) || empty($this->long_name)) {
			die("A widget must have a valid type and classname defined");
		}
		$widget_options = array('classname' => $this->css_classname, 'description' => __($this->description));
		$control_options = array('width' => $this->width, 'height' => $this->height);
		parent::__construct($this->short_name, $this->long_name, $widget_options, $control_options);
	}

	function _cleanOutputVariable($variable, $value) {
		if (is_string($value)) {
			return htmlspecialchars($value);
		}
		elseif (is_array($value)) {
			foreach ($value as $subvariable => $subvalue) {
				$value[$subvariable] = self::_cleanOutputVariable($subvariable, $subvalue);
			}
			return $value;
		}
		return $value;
	}

	function _cleanInputVariable($variable, $value) {
		if (is_string($value)) {
			return stripslashes($value);
		}
		elseif (is_array($value)) {
			foreach ($value as $subvariable => $subvalue) {
				$value[$subvariable] = self::_cleanInputVariable($subvariable, $subvalue);
			}
			return $value;
		}
		return $value;
	}

	function widget($args, $instance){
		global $gantry;
		extract($args);
		$defaults = $this->_defaults;
		$instance = wp_parse_args((array) $instance, $defaults);
		foreach ($instance as $variable => $value)
		{
			$$variable = self::_cleanOutputVariable($variable, $value);
			$instance[$variable] = $$variable;
		}

		$this->render($args, $instance);

	}

}

RokWeatherWidget::$plugin_path = dirname($plugin);
RokWeatherWidget::$plugin_url = WP_PLUGIN_URL . '/' . basename(RokWeatherWidget::$plugin_path);

add_action('widgets_init', array('RokWeatherWidget', 'init'));
add_action('wp_enqueue_scripts', array('RokWeather', 'rokweather_scripts'));
add_action('admin_enqueue_scripts', array('RokWeather', 'rokweather_admin_scripts'));
add_action('widgets_init', array('RokWeatherWidget', 'rokweather_init'));

// Add AJAX
add_action('wp_ajax_rokweather', array('RokWeatherWidget', 'rokweather_callback'));
add_action('wp_ajax_nopriv_rokweather', array('RokWeatherWidget', 'rokweather_callback'));

// Load Language
load_plugin_textdomain('rokweather', false, basename($rokweather_plugin_path) . '/languages/');

// MooTools Enqueue Script
add_action('init', 'rokweather_mootools_init', -50);

// Widget JS script
if(is_admin()) {
	add_action('admin_init', 'admin_rokweather_widget_script');
}

function rokweather_mootools_init(){
	global $rokweather_plugin_url;
	wp_register_script('mootools.js', $rokweather_plugin_url . '/tmpl/js/mootools.js');
	wp_enqueue_script('mootools.js');
}

function admin_rokweather_widget_script() {
	wp_register_script('rokweather_widget.js', RokWeatherWidget::$plugin_url.'/admin/rokweather_widget.js');
	wp_enqueue_script('rokweather_widget.js');
}

?>
